
# Type: disease or phenotypic feature association to thing association_subject




URI: [biolink:disease_or_phenotypic_feature_association_to_thing_association_subject](https://w3id.org/biolink/vocab/disease_or_phenotypic_feature_association_to_thing_association_subject)


## Domain and Range

[DiseaseOrPhenotypicFeatureAssociationToThingAssociation](DiseaseOrPhenotypicFeatureAssociationToThingAssociation.md) ->  <sub>REQ</sub> [DiseaseOrPhenotypicFeature](DiseaseOrPhenotypicFeature.md)

## Parents

 *  is_a: [subject](subject.md)

## Children


## Used by

 * [DiseaseOrPhenotypicFeatureAssociationToLocationAssociation](DiseaseOrPhenotypicFeatureAssociationToLocationAssociation.md)
 * [DiseaseOrPhenotypicFeatureAssociationToThingAssociation](DiseaseOrPhenotypicFeatureAssociationToThingAssociation.md)
